# sphinx-litprog

*A [Sphinx](https://www.sphinx-doc.org) extension for [literate programming](https://en.wikipedia.org/wiki/Literate_programming)*

For details, please refer to the [documentation](https://sphinx-litprog.readthedocs.io).
